Crate kube_utils

Crate kube_utils 

Minimal client for kubernetes internal API

If you need full fledged API client, then prefer to use kube-client

Modules

data
Minimal data model to allow extraction of only useful information (for the purposes of this crate)

Structs

Client
Client for internal API (i.e. to be used within cluster)
ClusterToken
Local cluster auth token read from mounted file system
HttpConfig
General HTTP config
KubeConfig
Kubernetes API config
Uri
The URI component of a request.

Enums

KubeError
Possible errors reading kube config

Functions

pod_name
Returns pod name using following environment variables: