ClusterToken

Struct ClusterToken 

pub struct ClusterToken { /* private fields */ }
Local cluster auth token read from mounted file system

Token is re-used for at most 1 minute, and unless file is missing, will be reloaded every time after 1 minute If it is impossible to refresh token, then existing token will be used (actual token validity is within 10 minutes)

Implementations

Source

impl ClusterToken

pub fn new_token(file: Cow<'static, str>) -> Result<Self, KubeError>

Creates new ClusterToken by performing initial fetch of the token at file location

Returns error if unable to fetch.

After this, file is assumed to be always valid, but if re-fetch fails, it will use existing token

pub fn is_expired(&self) -> bool

Checks if token is expired, returning true if that’s the case

pub fn refresh(&mut self) -> bool

Force refresh token, returning false if failed to read file

pub fn refresh_if_expired(&mut self) -> bool

Requests to perform token refresh if it expires

Returns true if token has been refreshed

pub fn token(&self) -> &str

Returns current token