Minimal client for kubernetes internal API
If you need full fledged API client, then prefer to use kube-client
Modules
- data
- Minimal data model to allow extraction of only useful information (for the purposes of this crate)
Structs
- Client
- Client for internal API (i.e. to be used within cluster)
- Cluster
Token - Local cluster auth token read from mounted file system
- Http
Config - General HTTP config
- Kube
Config - Kubernetes API config
- Uri
- The URI component of a request.
Enums
- Kube
Error - Possible errors reading kube config
Functions
- pod_
name - Returns pod name using following environment variables: